C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_ITRN2DIM  TRANSFER RAOB 2D DATA FOR A LEVEL TYPE - I
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-02-10
C
C ABSTRACT: TRANSFER RAOB 2D DATA FOR A LEVEL TYPE OF SPECIFIED DATA
C   TYPE FROM TEMPORARY ARRAYS TO CALLER'S ARRAYS.
C
C PROGRAM HISTORY LOG:
C   00-02-10  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL M_ITRN2DIM (NDLEV,NDSTA,NRECS,TDIM,TMP,LEVELS,NLEVELS,
C                            ARRAY)
C
C   INPUT ARGUMENT LIST:
C     NDLEV    - I       SIZE TO USE FOR LEVEL DIMENSION IN ARRAYS
C     NDSTA    - I       SIZE TO USE FOR STATION DIMENSION IN ARRAYS
C     NRECS    - I       NUMBER OF RECORDS AVAILABLE FOR THIS LEVEL TYPE
C     TDIM     - I       LEVELS DIMENSION TO USE FOR TEMPORARY ARRAYS
C     TMP      - IA      TEMPORARY ARRAY
C     LEVELS   - RA      NUMBER OF LEVELS FOR THIS LEVEL TYPE
C     NLEVELS  - IA      NUMBER OF LEVELS ALREADY FILLED IN ARRAY
C
C   OUTPUT ARGUMENT LIST:
C     ARRAY    - RA      CALLER'S ARRAY
C
C SUBPROGRAMS CALLED:
C     NONE
C
C REMARKS:
C     NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE M_ITRN2DIM (NDLEV,NDSTA,NRECS,TDIM,TMP,LEVELS,NLEVELS,
     1                       ARRAY)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NDLEV
      INTEGER NDSTA
      INTEGER NRECS
      INTEGER TDIM
      REAL TMP(TDIM,MXRAOB_P)
      REAL LEVELS(MXRAOB_P)
      INTEGER NLEVELS(NDSTA)
      INTEGER ARRAY(NDLEV,NDSTA)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,J


C     *****************************************************************
C     ******************* BEGIN OF M_ITRN2DIM *************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     FOR EACH RECORD, IF THE NUMBER OF LEVELS ISN'T MISSING, MOVE
C     DATA FROM THE TEMPORARY ARRAY TO THE CALLER'S ARRAY.
C     ------------------------------------------------------------------
      DO 1 J = 1, NRECS

         IF(LEVELS(J).NE.MISS_P)THEN

            DO 2 I = 1, INT(LEVELS(J))

               ARRAY(I+NLEVELS(J),J) = TMP(I,J)

 2          CONTINUE

         ENDIF

 1    CONTINUE

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
